from . import emmpm

def emmpm_filter(data_container_array, input_data_array_path = None, use_one_based_values = None, num_classes = None, exchange_energy = None, histogram_loops = None, segmentation_loops = None, emmpm_table_data = None, use_simulated_annealing = None, use_gradient_penalty = None, gradient_beta_e = None, use_curvature_penalty = None, curvature_beta_c = None, curvature_r_max = None, curvature_em_loop_delay = None, output_data_array_path = None, observer = None) -> int:
  """
  EMMPMFilter

  :param data_container_array | DataContainerArray
  :param input_data_array_path | DataArrayPath InputDataArrayPath
  :param use_one_based_values | bool UseOneBasedValues
  :param num_classes | int NumClasses
  :param exchange_energy | float ExchangeEnergy
  :param histogram_loops | int HistogramLoops
  :param segmentation_loops | int SegmentationLoops
  :param emmpm_table_data | DynamicTableData EMMPMTableData
  :param use_simulated_annealing | bool UseSimulatedAnnealing
  :param use_gradient_penalty | bool UseGradientPenalty
  :param gradient_beta_e | double GradientBetaE
  :param use_curvature_penalty | bool UseCurvaturePenalty
  :param curvature_beta_c | double CurvatureBetaC
  :param curvature_r_max | double CurvatureRMax
  :param curvature_em_loop_delay | int CurvatureEMLoopDelay
  :param output_data_array_path | DataArrayPath OutputDataArrayPath
  :param observer | Observer
  """

  filter = emmpm.EMMPMFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_data_array_path is not None:
    filter.InputDataArrayPath = input_data_array_path
  if use_one_based_values is not None:
    filter.UseOneBasedValues = use_one_based_values
  if num_classes is not None:
    filter.NumClasses = num_classes
  if exchange_energy is not None:
    filter.ExchangeEnergy = exchange_energy
  if histogram_loops is not None:
    filter.HistogramLoops = histogram_loops
  if segmentation_loops is not None:
    filter.SegmentationLoops = segmentation_loops
  if emmpm_table_data is not None:
    filter.EMMPMTableData = emmpm_table_data
  if use_simulated_annealing is not None:
    filter.UseSimulatedAnnealing = use_simulated_annealing
  if use_gradient_penalty is not None:
    filter.UseGradientPenalty = use_gradient_penalty
  if gradient_beta_e is not None:
    filter.GradientBetaE = gradient_beta_e
  if use_curvature_penalty is not None:
    filter.UseCurvaturePenalty = use_curvature_penalty
  if curvature_beta_c is not None:
    filter.CurvatureBetaC = curvature_beta_c
  if curvature_r_max is not None:
    filter.CurvatureRMax = curvature_r_max
  if curvature_em_loop_delay is not None:
    filter.CurvatureEMLoopDelay = curvature_em_loop_delay
  if output_data_array_path is not None:
    filter.OutputDataArrayPath = output_data_array_path
  filter.execute()
  return filter.ErrorCode

def multi_emmpm_filter(data_container_array, input_data_array_vector = None, output_attribute_matrix_name = None, output_array_prefix = None, use_previous_mu_sigma = None, observer = None) -> int:
  """
  MultiEmmpmFilter

  :param data_container_array | DataContainerArray
  :param input_data_array_vector | std::vector<DataArrayPath> InputDataArrayVector
  :param output_attribute_matrix_name | QString OutputAttributeMatrixName
  :param output_array_prefix | QString OutputArrayPrefix
  :param use_previous_mu_sigma | bool UsePreviousMuSigma
  :param observer | Observer
  """

  filter = emmpm.MultiEmmpmFilter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_data_array_vector is not None:
    filter.InputDataArrayVector = input_data_array_vector
  if output_attribute_matrix_name is not None:
    filter.OutputAttributeMatrixName = output_attribute_matrix_name
  if output_array_prefix is not None:
    filter.OutputArrayPrefix = output_array_prefix
  if use_previous_mu_sigma is not None:
    filter.UsePreviousMuSigma = use_previous_mu_sigma
  filter.execute()
  return filter.ErrorCode

